pub fn syscall_exec_continue(
_caller: &mut impl StoreTr<RuntimeContext>,
_context: &InterruptionHolder,
) -> (u64, i64, i32)Expand description
Continues an exec after an interruption, executing the delegated call.
pub fn syscall_exec_continue(
_caller: &mut impl StoreTr<RuntimeContext>,
_context: &InterruptionHolder,
) -> (u64, i64, i32)Continues an exec after an interruption, executing the delegated call.